/*
 * Linux/C based server for TiVo Home Media Option protocol
 *
 * Based on version 1.5.1 of
 *    "TiVo Connect Automatic Machine; Discovery Protocol Specification"
 * Based on version 1.1.0 of
 *    "TiVo Home Media Option; Music and Photos Server Protocol Specification"
 *
 * Dave Clemans, April 2003
 *
 * Copyright (C) 2003  Dave Clemans, Brian A. Lantz
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * 
 * See the file "COPYING" for more details.
 */

#include "globals.h"
#include <signal.h>


void htmlHeader (struct aMessage *msg, int isRoot, char *path)
{
   struct aDirectoryEntry* rootdir;
   int                     len;
   char*                   cp;

   	appendToMsg( msg, "<!DOCTYPE html PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\">\n" );
   	appendToMsg( msg, "<html>\n" );
   	appendToMsg( msg, "<head>\n" );
   	appendToMsg( msg, " <meta http-equiv=\"content-type\"\n" );
   	appendToMsg( msg, "  content=\"text/html\"; charset=ISO-8859-1\n" );
   	appendToMsg( msg, " <title>byRequest</title>\n" );
   	appendToMsg( msg, "</head>\n" );
   	appendToMsg( msg, "<body>\n" );
   	appendToMsg( msg, "<h1 style=\"text-align: center;\">byRequest</h1>\n" );
   	appendToMsg( msg, "<br>\n" );
   	appendToMsg( msg, "<hr style=\"width: 100%; height: 2px;\"><br>\n" );
   	appendToMsg( msg, "//%s", getHostname() );

   	if( !isRoot )
   	{
      		for( rootdir = getRootdir(); rootdir != NULL; rootdir = rootdir->next )
      		{
        		len = strlen( rootdir->name );
        		if( strncmp( path, rootdir->name, len ) == 0 )
        		{
        			if( path[ len ] == '/' || strlen( path ) == len )
        			{
        				cp = &path[ len ];
        				break;
        			}
        		}
      		}
      		if( rootdir != NULL )
         		appendToMsg( msg, "/%s%s", rootdir->description, cp );
      		else
         		appendToMsg( msg, "%s", path );
   	}
   
	appendToMsg( msg, "/...<br>\n" );
   	appendToMsg( msg, "<br>\n" );
   	appendToMsg( msg, "<ol>\n" );
}

void _htmlFooter (struct aMessage *msg)
{
   appendToMsg( msg, "<br>\n" );
   appendToMsg( msg, "<hr style=\"width: 100%; height: 2px;\"><br>\n" );
   appendToMsg( msg, "<div style=\"text-align: center;\">byRequest - <span\n" );
   appendToMsg( msg, " style=\"font-style: italic;\">Yet Another TiVo&reg; Home Media Option Server</span><br>\n" );
   appendToMsg( msg, "<span style=\"font-style: italic;\"></span>From <span\n" );
   appendToMsg( msg, " style=\"text-decoration: underline;\">The Land Of Mystery</span><br>\n" );
   appendToMsg( msg, "</div>" );
   appendToMsg( msg, "<br clear=\"all\">\n" );
   appendToMsg( msg, "</body>\n" );
   appendToMsg( msg, "</html>\n" );
}


void htmlFooter (struct aMessage *msg)
{
   appendToMsg( msg, "</ol>\n" );
   _htmlFooter (msg);
}

typedef void (*sigHandler)(int);

void htmlSend (int fd, struct aMessage *msg)
{
   sigHandler              prevPipeSig;
   char 		   buffer[256];

   prevPipeSig = signal( SIGPIPE, SIG_IGN );

   write( fd, HTTP_HEADER, HTTP_HEADER_LEN );
   sprintf( buffer, "Content-Length: %d\r\n", msg->size );
   write( fd, buffer, strlen( buffer ) );
   write( fd, "Content-Type: text/html\r\n", 25 );
   write( fd, "\r\n", 2 );
   write( fd, msg->msg, msg->size );

   signal( SIGPIPE, prevPipeSig );
}

#ifdef WEB_ADMIN
void htmlAdminHeader (struct aMessage* msg, char *url)
{
        appendToMsg (msg, "<html>\n\n<head>\n<meta http-equiv=\"Content-Language\" content=\"en-us\">\n");
	appendToMsg (msg, "<meta name=\"GENERATOR\" content=\"Microsoft FrontPage 5.0\">\n");
	appendToMsg (msg, "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=windows-1252\">\n");
	appendToMsg (msg, "<title>ByRequest Admin Interface</title>\n</head>\n\n");

	appendToMsg (msg, "<body>\n\n<center><h1>ByRequest Admin Interface</h1></center>\n");
	appendToMsg (msg, "<form method=\"POST\" action=\"%s\">\n", url);
	appendToMsg (msg, "<table border=\"0\" cellpadding=\"0\" cellspacing=\"5\" style=\"border-collapse: collapse\" width=\"100%\">\n");

}
#endif
