/*
 * $Id: ignore.c,v 1.4 2005/02/14 15:53:48 blantz Exp $
 *
 * Linux/C based server for TiVo Home Media Option protocol
 *
 * Based on version 1.5.1 of
 *    "TiVo Connect Automatic Machine; Discovery Protocol Specification"
 * Based on version 1.1.0 of
 *    "TiVo Home Media Option; Music and Photos Server Protocol Specification"
 *
 * Dave Clemans, April 2003
 *
 * Copyright (C) 2003  Dave Clemans
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * 
 * See the file "COPYING" for more details.
 *
 * $Log: ignore.c,v $
 * Revision 1.4  2005/02/14 15:53:48  blantz
 * Ported byRequest to MacOSX. Mainly involved providing an implentation
 * of hsearch_r and minor other changes
 *
 * Revision 1.3  2004/11/17 12:50:37  blantz
 * Added support to WEB_ADMIN for the 'ignore' command.
 *
 * Revision 1.2  2003/12/22 04:12:12  dcharno
 * Tobias H: FreeBSD patches
 *
 * Revision 1.1  2003/12/19 02:10:51  edgauthier
 * Initial version
 *
 *
 */

#include "globals.h"
#include <string.h>

#if defined( __FreeBSD__ )
   #include <gnuregex.h>
#else
   #include <regex.h>
#endif

#ifndef REG_NOERROR
#define REG_NOERROR 0
#endif

#define TRUE	1
#define FALSE	0

/* WARNING: not rentrant!!! */
regex_t ignore_re;
int	initcomplete = FALSE;

static char *ignoreString = NULL;

void initIgnore( char *re) {

  int stat;

  if (ignoreString != NULL)
	free (ignoreString);
  ignoreString = strdup (re);
  // are we already initialized? If so, free the previous
  if (initcomplete)
    regfree(&ignore_re);
  
  stat = regcomp (&ignore_re, re, REG_ICASE | REG_EXTENDED);

  if (stat == 0)
  {
    addToLog("Ignoring all files matchin REGEXP %s \n",re);
    initcomplete = TRUE;
  }
  else
  {
    addToLog("Error compiling Ignore REGEXP of %s, disregarding \n", re);
    initcomplete = FALSE;
  }
}

  
int ignoreFile(char *cp) {

  int stat;

  // If we aren't initialized, then don't ignore anything
  if (! initcomplete) return FALSE;

  stat = regexec(&ignore_re, cp, 0, NULL, 0);

  switch (stat)
  {
  case REG_NOERROR:
    return TRUE;
    break;
    
  case REG_NOMATCH:
    return FALSE;
    break;

  default:			// anything else is an error
    addToLog("Error executing REGEX on string %s \n", cp);
  }

  return FALSE;
}

char * getIgnoreString (void)
{
	return ignoreString;
}

/* Local Variables:	*/
/* tab-width:2			*/
/* End:							*/
